from pathlib import Path
import shutil
import sys

from scripts.common import is_multicolumn


TESSERACT_PATH = Path(sys.argv[1])
PERO_OCR_PATH = Path(sys.argv[2])
OUTPUT_PATH = Path(sys.argv[3])


def main() -> None:
    with (TESSERACT_PATH / 'list.txt').open('rt') as tf, \
            (PERO_OCR_PATH / 'list.txt').open('rt') as pf:
        tesseract_lines = list(tf)
        pero_ocr_lines = list(pf)

    for tesseract_line, pero_ocr_line in zip(tesseract_lines, pero_ocr_lines):
        tesseract_filename = Path(tesseract_line.rstrip('\r\n'))
        pero_ocr_filename = Path(pero_ocr_line.rstrip('\r\n'))

        input_tesseract_filename = (TESSERACT_PATH / tesseract_filename.stem).with_suffix('.txt')
        input_pero_ocr_filename = (PERO_OCR_PATH / pero_ocr_filename.stem).with_suffix('.txt')
        output_filename = (OUTPUT_PATH / pero_ocr_filename.stem).with_suffix('.txt')
        decision_filename = (OUTPUT_PATH / pero_ocr_filename.stem).with_suffix('.ground-truth')

        for suffix in ('hocr', 'tsv', 'box', 'page'):
            shutil.copy(
                (TESSERACT_PATH / tesseract_filename.stem).with_suffix(f'.{suffix}'),
                (OUTPUT_PATH / pero_ocr_filename.stem).with_suffix(f'.{suffix}'),
            )

        for suffix in ('xml', ):
            shutil.copy(
                (PERO_OCR_PATH / pero_ocr_filename.stem).with_suffix(f'.{suffix}'),
                (OUTPUT_PATH / pero_ocr_filename.stem).with_suffix(f'.{suffix}'),
            )

        with input_tesseract_filename.with_suffix('.hocr').open('rt') as f:
            hocr_content = f.read()

        if not hocr_content.strip():
            with output_filename.open('wt') as f:
                print(file=f)
            with decision_filename.open('wt') as f:
                print('empty', file=f)
            continue

        if is_multicolumn(input_tesseract_filename.with_suffix('.hocr')):
            shutil.copy(input_tesseract_filename, output_filename)
            with decision_filename.open('wt') as f:
                print('tesseract', file=f)
        else:
            shutil.copy(input_pero_ocr_filename, output_filename)
            with decision_filename.open('wt') as f:
                print('pero', file=f)


if __name__ == '__main__':
    main()
