# -*- coding:utf-8 -*-

import logging


LOGGING_FORMAT = '%(asctime)s - %(name)s - %(levelname)s - %(message)s'


if __name__ == '__main__':
    logging.basicConfig(level=logging.INFO, format=LOGGING_FORMAT)


from pathlib import Path
import shutil
import sys

from tqdm import tqdm

from .common import image_filename_to_book, read_facts


INPUT_DIRNAME = Path(sys.argv[0])
INPUT_UPSCALED_HIGH_CONFIDENCE_FILENAMES = sys.argv[1]
INPUT_OCR_ROOT_TESSERACT = Path(sys.argv[2])
INPUT_OCR_ROOT_GOOGLE = Path(sys.argv[3])
INPUT_OCR_ROOT_COMBINED = Path(sys.argv[4])
OUTPUT_ROOT = Path(sys.argv[5])

INPUT_UPSCALED_HIGH_CONFIDENCE_LIST = list(read_facts(INPUT_UPSCALED_HIGH_CONFIDENCE_FILENAMES))
INPUT_UPSCALED_HIGH_CONFIDENCE_DICT = dict(INPUT_UPSCALED_HIGH_CONFIDENCE_LIST)


def main(ocr_texts_directory=OUTPUT_ROOT):
    logger = logging.getLogger('produce_ocr_texts')

    ocr_texts_directory.mkdir()

    num_copied_texts_tesseract = 0
    num_copied_texts_google = 0
    num_copied_texts_combined = 0
    num_all = 0

    filenames = INPUT_UPSCALED_HIGH_CONFIDENCE_LIST
    filenames = tqdm(
        filenames,
        'Producing a dataset of OCR texts in {}/'.format(
            ocr_texts_directory,
        )
    )

    for downscaled_filename, upscaled_filename in filenames:
        num_all += 1

        basename = Path(upscaled_filename).parent / Path(upscaled_filename).stem

        book_id, page = image_filename_to_book(downscaled_filename)

        input_text_tesseract_filename = INPUT_OCR_ROOT_TESSERACT / f'{basename}.hocr'
        if input_text_tesseract_filename.exists():
            num_copied_texts_tesseract += 1
            output_text_tesseract_filename = ocr_texts_directory / f'{book_id}' / f'{page}.hocr'
            output_text_tesseract_filename.parent.mkdir(exist_ok=True)
            shutil.copy(input_text_tesseract_filename, output_text_tesseract_filename)

        input_text_google_filename = INPUT_OCR_ROOT_GOOGLE / f'{basename}.json'
        if input_text_google_filename.exists():
            num_copied_texts_google += 1
            output_text_google_filename = ocr_texts_directory / f'{book_id}' / f'{page}.json'
            output_text_google_filename.parent.mkdir(exist_ok=True)
            shutil.copy(input_text_google_filename, output_text_google_filename)

        input_text_combined_filename = INPUT_OCR_ROOT_COMBINED / f'{basename}.txt'
        if input_text_combined_filename.exists():
            num_copied_texts_combined += 1
            output_text_combined_filename = ocr_texts_directory / f'{book_id}' / f'{page}.txt'
            output_text_combined_filename.parent.mkdir(exist_ok=True)
            shutil.copy(input_text_combined_filename, output_text_combined_filename)

    logger.info(
        f'Copied {num_copied_texts_tesseract} Tesseract OCR texts, '
        f'{num_copied_texts_google} Google OCR texts, and '
        f'{num_copied_texts_combined} combined OCR texts out of all {num_all} pages.'
    )


if __name__ == '__main__':
    main()
